@@ -11,7 +11,7 @@
 # More details in the ``LICENSE`` file included in this package.
 
 """
-$Id: PloneArticleMultiPage.py,v 1.8 2006/07/20 10:01:38 glenfant Exp $
+$Id: PloneArticleMultiPage.py,v 1.9 2006/09/29 07:42:00 macadames Exp $
 """
 __author__  = ''
 __docformat__ = 'restructuredtext'
@@ -141,7 +141,7 @@ class PloneArticleMultiPage(ATCTOrderedFolder):
     def getPages(self):
         """Returns pages. All pages are PloneArticle"""
         
-        return self.contentValues(filter={'portal_type' : 'PloneArticle'})
+        return self.getFolderContents(contentFilter={'portal_type' : 'PloneArticle'},full_objects=True)
     
     security.declareProtected(CMFCorePermissions.View, 'getPageIndex')
     def getPageIndex(self, page):
