@@ -10,7 +10,7 @@
 # More details in the ``LICENSE`` file included in this package.
 
 """PloneArticleTool main class
-$Id: PloneArticleTool.py,v 1.24 2006/07/20 10:01:38 glenfant Exp $
+$Id: PloneArticleTool.py,v 1.26 2006/10/05 14:08:27 encolpe Exp $
 """
 
 # Python imports
@@ -39,6 +39,10 @@ from Products.Archetypes.interfaces.base import IBaseUnit
 from Products.PloneArticle.migration.Migrator import Migrator
 from config import *
 
+# CMFEditions
+if HAS_CMFEDITIONS:
+    from Products.PloneArticle.CMFEditionsModifier import PloneArticleV3CMFEModifier
+
 import TypelessPloneArticleProperties
 
 _www = os.path.join(os.path.dirname(__file__), 'www')
@@ -111,11 +115,12 @@ class PloneArticleTool(PropertyManager, UniqueObject, SimpleItem, ActionProvider
 
     security.declareProtected(CMFCorePermissions.ManagePortal, "setPreferences")
     def setPreferences(self, data):
-        """
-        setPreferences(self, data) => set preferences
+        """setPreferences(self, data) => set preferences
+
         Data is a dictionary. We use the archetypes stuff to set things,
         by calling each mutator method.
         """
+        self.updateCMFEditionsSupport(data.get('cmfeditions_support'))
         return TypelessPloneArticleProperties.updateTypelessPloneArticleProperties(
             self,
             data,
@@ -169,8 +174,7 @@ class PloneArticleTool(PropertyManager, UniqueObject, SimpleItem, ActionProvider
 
     security.declarePublic("hasLockSupport")
     def hasLockSupport(self,):
-        """
-        Return the lock support availability
+        """Return the lock support availability
         """
         ret = getattr(self, "lock_support", 0)
         return ret
@@ -183,6 +187,45 @@ class PloneArticleTool(PropertyManager, UniqueObject, SimpleItem, ActionProvider
 ##        self.lock_support = not not int(value)
 ##        Log(LOG_DEBUG, "lock support set to:", self.hasLockSupport())
 
+    security.declarePublic("hasLockSupport")
+    def hasCMFEditionsSupport(self,):
+        """Return the CMFEditions support availability
+        """
+        ret = getattr(self, 'cmfeditions_support', 0)
+        return ret
+
+    security.declareProtected(CMFCorePermissions.ManagePortal, 'updateCMFEditionsSupport')
+    def updateCMFEditionsSupport(self, value, **kwargs):
+        """Update CMFEditions configuration for PloneArticle
+
+        'on_edit' version policy don't have sense for plonearticle since
+        attachments, images and links modifications don't go through edit method.
+        """
+        if not HAS_CMFEDITIONS:
+            Log(LOG_ERROR, "CMFEditions cannot be imported")
+            return
+
+        rep_tool = getToolByName(self, 'portal_repository')
+        mod_tool = getToolByName(self, 'portal_modifier')
+        if value != getattr(self, 'cmfeditions_support', None):
+            if value:
+                # Instanciate and configure PloneArticle modifier
+                PloneArticleV3CMFEModifier.install(mod_tool)
+                modifier = mod_tool.get('PloneArticleV3Modifier')
+                modifier.edit(enabled=True,
+                              condition="python: hasattr(object, 'portal_type') and object.portal_type in ('PloneArticle', 'PloneArticleMultiPage')",
+                          )
+
+                # Enable PloneArticle versioning
+                rep_tool.setVersionableContentTypes(['PloneArticle', 'PloneArticleMultiPage'])
+                rep_tool.manage_setTypePolicies({
+                    'PloneArticle': ['version_on_revert'],
+                    'PloneArticleMultiPage': ['version_on_revert'],
+                })
+
+        # finally we set value
+        setattr(self, 'cmfeditions_support', value)
+
     security.declarePublic("getMaxAttachmentSize")
     def getMaxAttachmentSize(self):
         """ Return the max size of attachments"""
