@@ -10,7 +10,7 @@
 # More details in the ``LICENSE`` file included in this package.
 
 """PloneArticle properties
-$Id: TypelessPloneArticleProperties.py,v 1.5 2006/07/20 10:01:38 glenfant Exp $
+$Id: TypelessPloneArticleProperties.py,v 1.6 2006/09/18 20:49:59 encolpe Exp $
 """
 
 # Python imports
@@ -128,7 +128,7 @@ class TypelessPloneArticleProperties(SimpleItem, BaseObject, Role.RoleManager):
     archetype_name = "TypelessPloneArticleProperties"
     meta_type = "TypelessPloneArticleProperties"
     isPrincipiaFolderish = 0
- 
+
     def getAvailableTextFormatsVocabulary(self,):
         """vocabulary for text formats"""
         at = getToolByName(self, "portal_article")
@@ -200,6 +200,16 @@ class TypelessPloneArticleProperties(SimpleItem, BaseObject, Role.RoleManager):
                 i18n_domain = "plonearticle",
                 ),
             ),
+        BooleanField(
+            'cmfeditions_support',
+            group = "general",
+            accessor = "hasCMFEditionsSupport",
+            widget = BooleanWidget(
+                label_msgid = "label_cmfeditions_support",
+                description_msgid = "help_cmfeditions_support",
+                i18n_domain = "plonearticle",
+                ),
+            ),
 
         # Attachments
         StringField(
@@ -211,8 +221,8 @@ class TypelessPloneArticleProperties(SimpleItem, BaseObject, Role.RoleManager):
             vocabulary = "getAvailableAttachmentTypesVocabulary",
             widget = MultiSelectionWidget(
                 label_msgid = "label_referenceable_attachment_content_types_prefs",
-                i18n_domain = "plonearticle",
                 description_msgid = "help_referenceable_attachment_content_types_prefs",
+                i18n_domain = "plonearticle",
                 ),
             ),
         StringField(
@@ -223,8 +233,8 @@ class TypelessPloneArticleProperties(SimpleItem, BaseObject, Role.RoleManager):
             vocabulary = "getAvailableAttachmentTypesWithUndefinedVocabulary",
             widget = SelectionWidget(
                 label_msgid = "label_attachment_content_type_prefs",
-                i18n_domain = "plonearticle",
                 description_msgid = "help_attachment_content_type_prefs",
+                i18n_domain = "plonearticle",
                 ),
             ),
         IntegerField(
@@ -259,8 +269,8 @@ class TypelessPloneArticleProperties(SimpleItem, BaseObject, Role.RoleManager):
             vocabulary = "getAvailableImageTypesVocabulary",
             widget = MultiSelectionWidget(
                 label_msgid = "label_referenceable_image_content_types_prefs",
-                i18n_domain = "plonearticle",
                 description_msgid = "help_referenceable_image_content_types_prefs",
+                i18n_domain = "plonearticle",
                 ),
             ),
         StringField(
@@ -271,8 +281,8 @@ class TypelessPloneArticleProperties(SimpleItem, BaseObject, Role.RoleManager):
             vocabulary = "getAvailableImageTypesWithUndefinedVocabulary",
             widget = SelectionWidget(
                 label_msgid = "label_image_content_type_prefs",
-                i18n_domain = "plonearticle",
                 description_msgid = "help_image_content_type_prefs",
+                i18n_domain = "plonearticle",
                 ),
             ),
         IntegerField(
@@ -297,8 +307,8 @@ class TypelessPloneArticleProperties(SimpleItem, BaseObject, Role.RoleManager):
             vocabulary = "getAvailableLinkTypesVocabulary",
             widget = MultiSelectionWidget(
                 label_msgid = "label_referenceable_link_content_types_prefs",
-                i18n_domain = "plonearticle",
                 description_msgid = "help_referenceable_link_content_types_prefs",
+                i18n_domain = "plonearticle",
                 ),
             ),
         StringField(
@@ -309,8 +319,8 @@ class TypelessPloneArticleProperties(SimpleItem, BaseObject, Role.RoleManager):
             vocabulary = "getAvailableLinkTypesWithUndefinedVocabulary",
             widget = SelectionWidget(
                 label_msgid = "label_link_content_type_prefs",
-                i18n_domain = "plonearticle",
                 description_msgid = "help_link_content_type_prefs",
+                i18n_domain = "plonearticle",
                 ),
             ),
         ),
