@@ -1,5 +1,16 @@
+# Copyright (c) 2003-2006 Ingeniweb SAS
+
+# This software is subject to the provisions of the GNU General Public
+# License, Version 2.0 (GPL).  A copy of the GPL should accompany this
+# distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
+# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY,
+# AGAINST INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE
+
+# More details in the ``LICENSE`` file included in this package.
+
 """
-$Id: IAttachment.py,v 1.2 2004/12/28 10:38:36 pjgrizel Exp $
+$Id: IAttachment.py,v 1.5 2006/07/20 10:01:39 glenfant Exp $
 """
 __author__  = ''
 __docformat__ = 'restructuredtext'
