@@ -11,7 +11,7 @@
 
 """PloneArticle tests
 
-$Id: PloneArticleTestCase.py,v 1.6 2006/07/20 11:55:59 glenfant Exp $
+$Id: PloneArticleTestCase.py,v 1.9 2006/09/18 20:52:55 encolpe Exp $
 """
 
 __author__ = ''
@@ -54,7 +54,7 @@ else:
 class PloneArticleTestCase(PloneTestCase.PloneTestCase):
     """ PloneArticle test case based on a plone site"""
 
-    
+
     def afterSetUp(self):
         # Tools shortcuts
         self.type_tool = getToolByName(self.portal, 'portal_types')
@@ -66,7 +66,7 @@ class PloneArticleTestCase(PloneTestCase.PloneTestCase):
         except:
             pass # Already done
         self.member_folder = self.mb_tool.getHomeFolder(portal_member)
-    
+
     def createEmptyArticle(self, container, content_id = 'article'):
         # return empty article
         container.invokeFactory(type_name='PloneArticle', id=content_id)
@@ -77,40 +77,41 @@ class PloneArticleTestCase(PloneTestCase.PloneTestCase):
         self.assertEqual(len(article.getAttachments()), 0)
         self.assertEqual(len(article.getImages()), 0)
         return article
-    
+
     def createExternalFile(self, container=None, content_id='external_file'):
         container = container or self.member_folder
         container.invokeFactory(type_name=FILE_PORTAL_TYPE, id=content_id)
         self.failUnless(content_id in container.objectIds())
         return getattr(container, content_id)
-    
+
     def createArticle(self, container):
-        # Content creation
-        
+        """Create content in self.article
+        """
+
         # Add a file not in PloneArticle
         self.external_file = self.createExternalFile(container)
-        
+
         # Add an image not in PloneArticle
         content_id = 'external_image'
         container.invokeFactory(type_name=IMAGE_PORTAL_TYPE, id=content_id)
         self.failUnless(content_id in container.objectIds())
         self.external_image = getattr(container, content_id)
-        
+
         #create empty article
         self.article = self.createEmptyArticle(container)
-        
-        # Add a file in article 
+
+        # Add a file in article
         content_id = 'article_file'
         self.article.invokeFactory(type_name=FILE_PORTAL_TYPE, id=content_id)
         self.failUnless(content_id in self.article.objectIds())
         self.article_file = getattr(self.article, content_id)
-        
+
         # Add an image in article
         content_id = 'article_image'
         self.article.invokeFactory(type_name=IMAGE_PORTAL_TYPE, id=content_id)
         self.failUnless(content_id in self.article.objectIds())
         self.article_image = getattr(self.article, content_id)
-        
+
         # Add files and images as references of article
         self.article.addAttachmentFromObject(self.external_file)
         self.failUnless(self.external_file.UID() in self.article.getAttachmentUIDs())
@@ -120,17 +121,18 @@ class PloneArticleTestCase(PloneTestCase.PloneTestCase):
         self.failUnless(self.article_file.UID() in self.article.getAttachmentUIDs())
         self.article.addImageFromObject(self.article_image)
         self.failUnless(self.article_image.UID() in self.article.getImageUIDs())
+        return self.article
 
     def beforeTearDown(self):
         # logout
         noSecurityManager()
-    
+
     def loginAsPortalMember(self):
         '''Use if you need to manipulate an article as member.'''
         uf = self.portal.acl_users
         user = uf.getUserById(portal_member).__of__(uf)
         newSecurityManager(None, user)
-        
+
     def loginAsPortalOwner(self):
         '''Use if you need to manipulate an article as member.'''
         uf = self.app.acl_users
@@ -141,13 +143,13 @@ def setupPloneArticle(app, quiet=0):
     get_transaction().begin()
     _start = time.time()
     portal = app.portal
-    
+
     if not quiet: ZopeTestCase._print('Installing PloneArticle ... ')
 
     # login as manager
     user = app.acl_users.getUserById(portal_owner).__of__(app.acl_users)
     newSecurityManager(None, user)
-    
+
     # add ATCT on Plone up to 2.0
     if not pa_config.HAS_PLONE_2_1:
         if hasattr(aq_base(portal), 'switchCMF2ATCT'):
@@ -160,15 +162,30 @@ def setupPloneArticle(app, quiet=0):
         ZopeTestCase._print('PloneArticle already installed ... ')
     else:
         installPloneArticle(portal)
-    
+
     # Configure Portal article
     article_tool = portal.portal_article
     article_tool.allowed_image_type = IMAGE_PORTAL_TYPE
     article_tool.allowed_attachment_type = FILE_PORTAL_TYPE
-    
+
     # Create portal member
     portal.portal_registration.addMember(portal_member, 'azerty', ['Member'])
-    
+
+    # If CMFEditions is there we install and configure it.
+    if pa_config.HAS_CMFEDITIONS:
+        qi_tool = getToolByName(portal, 'portal_quickinstaller', None)
+
+        ZopeTestCase.installProduct('CMFEditions', quiet=1)
+        ZopeTestCase.installProduct('CMFDiffTool', quiet=1)
+
+        qi_tool.installProduct('CMFEditions')
+        get_transaction().commit(1)
+        qi_tool.installProduct('CMFDiffTool')
+        get_transaction().commit(1)
+
+        article_tool.updateCMFEditionsSupport(value=1)
+
+
     # Log out
     noSecurityManager()
     get_transaction().commit()
