@@ -13,7 +13,7 @@
 
 common includes a set of basic things that every test needs.
 
-$Id: common.py,v 1.6 2006/07/20 11:55:59 glenfant Exp $
+$Id: common.py,v 1.7 2006/09/04 12:58:13 encolpe Exp $
 """
 
 __author__ = ''
@@ -45,6 +45,7 @@ def dcEdit(obj):
 
 from AccessControl.SecurityManagement import newSecurityManager
 from AccessControl.SecurityManagement import noSecurityManager
+from pprint import PrettyPrinter
 
 ###
 # general test suits including products
@@ -128,5 +129,5 @@ else:
 # PloneArticle tests
 ###
 
-from PloneArticleTestCase import PloneArticleTestCase, FILE_PORTAL_TYPE, IMAGE_PORTAL_TYPE
+from PloneArticleTestCase import PloneArticleTestCase, FILE_PORTAL_TYPE, IMAGE_PORTAL_TYPE, pa_config
 from Products.PloneArticle.interfaces.IArticle import IArticleAttachments, IArticleImages
