@@ -12,7 +12,7 @@
 """
 PloneArticle base test
 
-$Id: testPloneArticle.py,v 1.13 2006/07/20 11:56:00 glenfant Exp $
+$Id: testPloneArticle.py,v 1.15 2006/09/18 20:52:55 encolpe Exp $
 """
 
 from common import *
@@ -29,13 +29,13 @@ class TestFile:
 tests = []
 
 class TestPloneArticle(PloneArticleTestCase):
-    
+
     def testCreateArticle(self, ):
         """
         """
         self.loginAsPortalMember()
         self.article = self.createEmptyArticle(self.member_folder)
-        
+
     def testEditArticle(self, ):
         """
         Editing article
@@ -44,23 +44,23 @@ class TestPloneArticle(PloneArticleTestCase):
         title = "A dummy title"
         text = "<p>My dummy text</p>"
         description = "A dummy description"
-        
+
         # Edit content
         self.article.edit(text = text, title = title, description = description, text_format = 'html')
-        
+
         # test if everything is ok
         self.failUnless(self.article.Title() == title, "Value is %s" % self.article.Title())
         self.failUnless(self.article.Description() == description, "Value is %s" % self.article.Description())
         self.failUnless(self.article.getText() == text, "Value is %s" % self.article.getText())
-        
-        
+
+
     def addAttachment(self, container=None, title = 'attachment_title', description = 'attachment_description'):
         """
         """
         container = container or self.testCreateArticle()
         self.article.addAttachment(self, title, description, file=TestFile())
-        
-    
+
+
     def testAddAttachment(self, ):
         """
         """
@@ -70,7 +70,7 @@ class TestPloneArticle(PloneArticleTestCase):
         attachments = contents[0].getContents(self.article)
         #the article has only one attachment
         self.assertEqual(1, len(attachments))
-        
+
         #the attachment added is an ATFile
         self.assertEqual(self.portal.portal_types.getTypeInfo(FILE_PORTAL_TYPE),
                          attachments[0].getTypeInfo())
@@ -82,20 +82,20 @@ class TestPloneArticle(PloneArticleTestCase):
         """
         #test content
         self.assertEqual('file_contents', str(attachments[0]))
-        
-        
-        
+
+
+
     def testGetAttachment(self, ):
         """
         """
         self.testAddAttachment()
         contents = self.article.article_contents
         attachments = contents[0].getContents(self.article)
-        
+
         #attachment uid is non existant
         uid = 'No chance it exists'
         self.assertEqual(self.article.getAttachment(uid), None)
-        
+
         #get the uid of added attachment
         uid = attachments[0].UID()
         #get attachment by uid
@@ -104,7 +104,7 @@ class TestPloneArticle(PloneArticleTestCase):
         #the return attachment is an ATFile
         self.assertEqual(self.portal.portal_types.getTypeInfo(FILE_PORTAL_TYPE),
                          attachment.getTypeInfo())
-    
+
     def testGetAttachmentBrain(self, ):
         """
         """
@@ -113,13 +113,13 @@ class TestPloneArticle(PloneArticleTestCase):
         attachments = contents[0].getContents(self.article)
         uid = attachments[0].UID()
         brain = self.article.getAttachmentBrain(uid)
-        
+
         #getAttachmentBrain return an ArticleReferenceBrain
         from Products.PloneArticle.ArticleCore import ArticleReferenceBrain
         self.failUnless(isinstance(brain, ArticleReferenceBrain),
                         'Value is %s' % type(brain))
-    
-    
+
+
     def testGetAttachments(self, ):
         """
         """
@@ -129,7 +129,7 @@ class TestPloneArticle(PloneArticleTestCase):
         self.addAttachment(self.article, 'title2', 'desc2')
         attachments = self.article.getAttachments()
         self.assertEqual(2, len(attachments))
-    
+
     def testGetAttachmentBrains(self,):
         """
         """
@@ -137,13 +137,13 @@ class TestPloneArticle(PloneArticleTestCase):
         external_file = self.createExternalFile()
         self.article.addAttachmentFromObject(external_file)
         brains = self.article.getAttachmentBrains()
-        
+
         #getAttachmentBrains return an ArticleReferenceBrain
         from Products.PloneArticle.ArticleCore import ArticleReferenceBrain
         self.failUnless(isinstance(brains[0], ArticleReferenceBrain),
                         'Value is %s' % type(brains[0]))
 
-    
+
     def testGetAttachmentUIDs(self, ):
         """
         """
@@ -157,7 +157,7 @@ class TestPloneArticle(PloneArticleTestCase):
         self.failUnless(external_file.UID() in self.article.getAttachmentUIDs())
         # same length
         self.assertEqual(len(uids), len(attachments))
-        
+
     def testAddAttachmentFromObject(self, ):
         """
         """
@@ -170,7 +170,7 @@ class TestPloneArticle(PloneArticleTestCase):
         #added object is return as reference
         ref = self.article.getAttachmentBrain(external_file.UID())
         self.assertEqual(ref.getObject(), obj)
-        
+
     def testAddAttachmentFromUID(self, ):
         """
         """
@@ -193,7 +193,7 @@ class TestPloneArticle(PloneArticleTestCase):
         self.article.editAttachment(uid, title, description)
         self.failUnless(attachment.Title() == title, "Value is %s" % attachment.Title())
         self.failUnless(attachment.Description() == description, "Value is %s" % attachment.Description())
-    
+
     def testEditAttachments(self, ):
         """
         Edit attachments.
@@ -206,8 +206,8 @@ class TestPloneArticle(PloneArticleTestCase):
         title = 'a title'
         description = 'a description'
         attachments = [
-          {'UID': attachment.UID(), 
-           'title': title, 
+          {'UID': attachment.UID(),
+           'title': title,
            'description': description
           } for attachment in self.article.getAttachments()
         ]
@@ -216,9 +216,9 @@ class TestPloneArticle(PloneArticleTestCase):
         attach2 = self.article.getAttachments()[1]
         self.assertEqual(attach1.Title(), title)
         self.assertEqual(attach1.Description(), description)
-    
+
     def testRemoveAttachment(self, ):
-        """
+        """ Remove one attachment
         """
         self.testAddAttachment()
         self.addAttachment(container=self.article)
@@ -227,9 +227,9 @@ class TestPloneArticle(PloneArticleTestCase):
         uid = uids[1]
         self.article.removeAttachment(uid)
         self.assertEqual(None, self.article.getAttachment(uid))
-    
+
     def testRemoveAttachments(self, ):
-        """
+        """ Remove all attachments
         """
         self.testAddAttachment()
         self.addAttachment(container=self.article)
@@ -237,8 +237,8 @@ class TestPloneArticle(PloneArticleTestCase):
         uids = [attachment.UID() for attachment in attachments]
         self.article.removeAttachments(uids)
         self.assertEqual([], self.article.getAttachments())
-    
-    
+
+
     def testMoveAttachmentsByDelta(self, ):
         """
         """
@@ -246,28 +246,28 @@ class TestPloneArticle(PloneArticleTestCase):
         self.addAttachment(container=self.article)
         attach1 = self.article.getAttachments()[0]
         attach2 = self.article.getAttachments()[1]
-    
+
     def testCopyAttachmentsToClipboard(self, ):
         """ TODO
         """
         pass
-    
+
     def testIsAttachmentContained(self, ):
         """ TODO
         """
         pass
-        
+
     def testCopyArticle(self,):
         """ Copy article
         """
-        
+
         self.loginAsPortalMember()
         self.createArticle(self.member_folder)
         article_id = self.article.getId()
         cb = self.member_folder.manage_copyObjects(ids=[article_id])
         self.member_folder.manage_pasteObjects(cb_copy_data=cb)
         new_article = getattr(self.member_folder, 'copy_of_%s' % article_id)
-        
+
         attachment_uids = new_article.getAttachmentUIDs()
         image_uids = new_article.getImageUIDs()
         self.assertEqual(len(attachment_uids), 2)
@@ -277,7 +277,7 @@ class TestPloneArticle(PloneArticleTestCase):
         self.failUnless(self.article_file.UID() not in attachment_uids)
         self.failUnless(self.article_image.UID() not in image_uids)
         self.logout()
-        
+
     def testCutArticle(self,):
         """ Cut article
         """
@@ -290,15 +290,15 @@ class TestPloneArticle(PloneArticleTestCase):
         new_folder_id = 'test'
         self.member_folder.invokeFactory(type_name='Folder', id=new_folder_id)
         new_folder = getattr(self.member_folder, new_folder_id)
-        
+
         # make sure we have _p_jar
         get_transaction().commit(1)
-        
+
         # Cut / Paste
         cb = self.member_folder.manage_cutObjects(ids=[article_id])
         new_folder.manage_pasteObjects(cb_copy_data=cb)
         new_article = getattr(self.member_folder, article_id)
-        
+
         article_file = getattr(new_article, 'article_file', None)
         self.failUnless(article_file is not None)
         article_image = getattr(new_article, 'article_image', None)
@@ -312,22 +312,22 @@ class TestPloneArticle(PloneArticleTestCase):
         self.failUnless(article_file.UID() in attachment_uids)
         self.failUnless(article_image.UID() in image_uids)
         self.logout()
-        
+
     def testRenameArticle(self,):
         """ Rename article
         """
-        
+
         self.loginAsPortalMember()
         self.createArticle(self.member_folder)
         article_id = self.article.getId()
-        
+
         # make sure we have _p_jar
         get_transaction().commit(1)
-        
+
         # Rename article
         new_article_id = 'new_article'
         self.member_folder.manage_renameObject(article_id, new_article_id)
-        
+
         # Test renamed article
         new_article = getattr(self.member_folder, new_article_id)
         article_file = getattr(new_article, 'article_file', None)
@@ -343,7 +343,7 @@ class TestPloneArticle(PloneArticleTestCase):
         self.failUnless(article_file.UID() in attachment_uids)
         self.failUnless(article_image.UID() in image_uids)
         self.logout()
-    
+
     #
     # TOOL TESTS
     #
@@ -357,11 +357,11 @@ class TestPloneArticle(PloneArticleTestCase):
         """
         Test max attachment size setting in Plone Article Tool
         """
-        
+
         portal_article = getToolByName(self.portal, 'portal_article')
         # Default should be 0: Unlimited
         self.failUnless(portal_article.getMaxAttachmentSize() == 0)
-        
+
         # Change to size
         portal_article.max_attachment_size = size
         self.failUnless(portal_article.getMaxAttachmentSize() == size)
@@ -371,7 +371,7 @@ class TestPloneArticle(PloneArticleTestCase):
         """
         Test max attachment size setting in Plone Article Tool
         """
-        
+
         portal_article = getToolByName(self.portal, 'portal_article')
         # Default should be 0: Unlimited
         self.failUnless(portal_article.getMaxImageSize() == 0)
@@ -383,49 +383,59 @@ class TestPloneArticle(PloneArticleTestCase):
     def testArticleToolLockSupport(self,):
         """
         """
-        
+
         portal_article = getToolByName(self.portal, 'portal_article')
         hasLockSupport = portal_article.hasLockSupport()
-        
+
         #default is 0
         self.assertEqual(hasLockSupport, 0)
-        
+
+    def testArticleToolCMFEditionsSupport(self,):
+        """
+        """
+
+        portal_article = getToolByName(self.portal, 'portal_article')
+        hasCMFEditionsSupport = portal_article.hasCMFEditionsSupport()
+
+        #default is 0
+        self.assertEqual(hasCMFEditionsSupport, 0)
+
     def testPloneArticleToolPreview(self,):
         """
         Test preview setting in Plone Article Tool
         """
-        
+
         portal_article = getToolByName(self.portal, 'portal_article')
-        
+
         # Default should be 1: Switched on
         self.failUnless(portal_article.isPreviewActivated() == 1)
 
         # Change to 0
         portal_article.preview_activated = 0
         self.failUnless(portal_article.isPreviewActivated() == 0)
-        
+
         # Change to 1
         portal_article.preview_activated = 1
         self.failUnless(portal_article.isPreviewActivated() == 1)
 
-        
+
 
     def TODO_testPloneArticleToolTextFormat(self,):
         """
         Test text format setting in Plone Article Tool
         """
         portal_article = getToolByName(self.portal, 'portal_article')
-        
+
         # Default should be ...
         #self.assertEqual(portal_article.getSiteTextFormats(), ('html', ))
-        
+
         # Should be html, plain and structured-text
         self.failUnless(
             portal_article.getAvailableTextFormats() == [
                 'html', 'plain', 'structured-text',
                 ],
             )
-        
+
         # Structured Text
         portal_article.setSiteTextFormats(['structured-text',])
         self.assertEqual(portal_article.getSiteTextFormats(), ('structured-text', ))
@@ -433,7 +443,7 @@ class TestPloneArticle(PloneArticleTestCase):
         # HTML
         portal_article.setSiteTextFormats(['html',])
         self.assertEqual(portal_article.getSiteTextFormats(), ('html', ))
-        
+
         #self.failUnless('html' in self.portal_article.getSiteTextFormats())
         #self.failIf('plain' in self.portal_article.getSiteTextFormats())
         #self.failIf('structured-text' in self.portal_article.getSiteTextFormats())
@@ -441,10 +451,10 @@ class TestPloneArticle(PloneArticleTestCase):
         # Plain text
         portal_article.setSiteTextFormats(['plain'])
         self.assertEqual(
-            portal_article.getSiteTextFormats(), 
+            portal_article.getSiteTextFormats(),
             ('plain', )
         )
-        
+
         #self.failUnless('plain' in self.portal_article.getSiteTextFormats())
         #self.failIf('html' in self.portal_article.getSiteTextFormats())
         #self.failIf('structured-text' in self.portal_article.getSiteTextFormats())
@@ -452,7 +462,7 @@ class TestPloneArticle(PloneArticleTestCase):
         # Should be plain and structured-text
         portal_article.setSiteTextFormats(['plain','structured-text'])
         self.assertEqual(
-            portal_article.getSiteTextFormats(), 
+            portal_article.getSiteTextFormats(),
             ('plain','structured-text')
         )
 
@@ -463,18 +473,18 @@ class TestPloneArticle(PloneArticleTestCase):
         # Should be html, plain and structured-text
         portal_article.setSiteTextFormats(['plain','html','structured-text'])
         self.assertEqual(
-            portal_article.getSiteTextFormats(), 
+            portal_article.getSiteTextFormats(),
             ('plain','html','structured-text', )
         )
-        
+
         #self.failUnless('plain' in self.portal_article.getSiteTextFormats())
         #self.failUnless('structured-text' in self.portal_article.getSiteTextFormats())
         #self.failUnless('html' in self.portal_article.getSiteTextFormats())
-        
+
         # Should be html and structured-text
         portal_article.setSiteTextFormats(['plain','structured-text'])
         self.assertEqual(
-            portal_article.getSiteTextFormats(), 
+            portal_article.getSiteTextFormats(),
             ('plain','structured-text', )
         )
 
@@ -490,17 +500,17 @@ class TestPloneArticle(PloneArticleTestCase):
         # Check that model exists and is default
         self.failUnless(model is not None)
         self.failUnless(model == "plonearticle_model")
-        
+
     def testSetModel(self,):
         """
         Test model changing
         """
-        
+
         portal_article = getToolByName(self.portal, 'portal_article')
         self.testCreateArticle()
         #test the default situation : only 8 model can be chosen
         self.assertEqual(len(portal_article.getSiteModels()), 8)
-        
+
         # Set a valid model
         site_models = portal_article.getAvailableModels()
         portal_article.site_models = site_models
@@ -522,8 +532,8 @@ class TestPloneArticle(PloneArticleTestCase):
         self.article.model = "ZORGLUB"
         model = self.article.getModel()
         self.failUnless(model == "plonearticle_model")
-        
-        
+
+
 tests.append(TestPloneArticle)
 
 if __name__ == '__main__':
